herosdevices.hardware.ids.peak_camera - Heros Devices 0.6.0 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.ids.peak_camera

Driver for cameras based on the ids peak library.

## Module Contents

herosdevices.hardware.ids.peak_camera.ids_peak = None

herosdevices.hardware.ids.peak_camera.DEFAULT_CONFIG

class herosdevices.hardware.ids.peak_camera.PeakCompatibleCamera(cam_id: str, config_dict: dict, default_config: str | None = None, lib_path: str | None = None, reset_to_continuous: bool = False)

  Bases: `herosdevices.core.templates.camera.CameraTemplate`

  A class to interface with IDS Peak cameras.

  The class provides functionality to control and capture images from IDS Peak cameras. It manages camera configuration, acquisition, and data streaming.

  Note

  To access the camera as non-root user, you need to add the following udev rule to `/etc/udev/rules.d/99-ids.rules`:

      ATTRS{idVendor}=="1409", MODE="666"

  The vendor library must be obtained from the [official website](https://en.ids-imaging.com/download-peak.html). Download the IDS peak archive file, unpack it at move the content of idspeak/ids/cti/ to a place where the user running the driver can access it. This path then needs to be specified via the lib_path argument (see example below)

  Note

  The `node_map` attribute provides access to the camera node map. If you need to set some special nodes you can use that. You can find the available nodes in the official API manuals:

  - https://en.ids-imaging.com/manuals/ids-peak/ids-peak-api-documentation/2.16.0/en/index.html

  - https://en.ids-imaging.com/manuals/ids-peak/ids-peak-user-manual/1.3.0/en/preface.html

  Example

  The class can be started with BOSS with the following example JSON dict:

      {
        "_id": "my_camera",
        "classname": "herosdevices.hardware.ids.PeakCompatibleCamera",
        "arguments": {
          "cam_id": "1410d4e7c3b5",
          "lib_path": "/opt/idspeak/ids/cti/",
          "default_config": "default",
          "config_dict": {
            "default": {
              "ExposureTime": 1000,
              "TriggerSelector": "ExposureStart",
              "TriggerMode": "On",
              "TriggerSource": "Software",
              "AcquisitionMode": "MultiFrame",
              "AcquisitionFrameCount": 5,
          }
        }
      }

  The keys in the config dictionary starting with a capital letter are nodes in the camera node map.

  node_map: ids_peak.ids_peak.NodeMap | None = None
  cam_id
  default_config_dict
  reset_to_continuous = False
  get_config_nodes(only_implemented: bool = True) → dict

    Get all nodes from the camera in form of a dict including information about if they can be set/read.

    Parameters:

      only_implemented – Shows only nodes that are implemented on the attached camera. If False, returns all nodes the driver library knows

  get_camera
  acquisition_running: bool = False
  payload_metadata: dict
  keep_device_open = True
  default_config: str
  get_device() → collections.abc.Iterator[None]

    Yield a device handle.

        # use the device in a with statement
        with self.get_device() as camera:
            camera.do_something()

  open() → Any

    Open the device handler and assign it to self._device.

  teardown() → None

    Release the device handler and potentially de-initialize the API.

  start() → bool

    Fire a software trigger.

    Returns:

      True if successful

  stop() → bool

    Abort the exposure and release queued buffers.

    Returns:

      True if successful

  reset() → None

    Reset the device by aborting any ongoing exposure, closing and re-opening the handler.

  get_status() → dict

    Get a dict with the current device status.

    Returns:

      A dict with the device status

  property config_dict: dict

    Get a copy of the configuration dict.

    Returns:

      Copy of the configuration dict

  update_configuration(new_config_dict: dict, merge: bool = True) → None

    Update the configuration dict with new configuration.

    Each dict key corresponds a (new) configuration name. Each value is a dict with config property -> config value.

    Parameters:

      - new_config_dict – A dict of configurations where the keys are the configuration names

      - merge – If `True`, the new dict is recursively merged with the current set config dict. If `False` the old configurations with the provided names (keys) are overwritten.

  get_configuration() → dict

    Get the currently active configuration.

    Returns:

      The currently active configuration.

  configure(config: str = '', metadata: dict | None = None) → bool

    Configure the device with the known configuration config.

    To add a configuration to the device, use `update_configuration()`.

    Parameters:

      - config – Key (name) of the configuration

      - metadata – Metadata that is merged into the current payload metadata dict which is send with every emitted `acquisition_data` event.

  set_configuration
  update_payload_metadata(metadata: dict, merge: bool = True) → None

    Update metadata dict send with every emitted frame by the `acquisition_data` event method.

    Parameters:

      - metadata – Metadata that is merged into the current payload metadata dict which is send with every emitted `acquisition_data` event.

      - merge – If `True`, the new dict is merged with the current set metadata dict. If `False` the old metadata is overwritten by the given dict.

  arm(metadata: dict | None = None, kill_running: bool = False) → bool

    Arm the device with the currently active configuration.

    Parameters:

      - metadata – Metadata that is merged into the current payload metadata dict which is send with every emitted `acquisition_data` event.

      - kill_running – If `True` any running acquisition will be stopped. If `False` and an acquisition is

      - running (already)

      - raised. (an error will be)

    Returns:

      True if arming was successful else False

  acquisition_data(frame: numpy.ndarray, metadata: dict | None = None) → tuple

    Event to emit new frames.

    Note

    The dtype of the frame is not changed here.

    Parameters:

      - frame – The frame payload data (for example an image or an scope trace)

      - metadata – The metadata which is passed along the payload. This argument takes precedence over the `payload_metadata` attribute (for example set by the `update_payload_metadata` method) while merging the two dicts.

    Returns:

      A tuple of image and metadata(-dict)

  acquisition_started(metadata: dict | None = None) → dict

    Event emitted when the acquisition thread starts.

    Returns:

      A dict with acquisition metadata

  acquisition_stopped(metadata: dict | None = None) → dict

    Event emitted when the acquisition thread stops.

    Returns:

      A dict with acquisition metadata